/*Copyright (C) 2019 Centro de Computacao Cientifica e Software Livre
Departamento de Informatica - Universidade Federal do Parana

This file is part of Plataforma Integrada MEC.

Plataforma Integrada MEC is free software: you can redistribute it and/or modify
it under the terms of the GNU Affero General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

Plataforma Integrada MEC is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Affero General Public License for more details.

You should have received a copy of the GNU Affero General Public License
along with Plataforma Integrada MEC.  If not, see <http://www.gnu.org/licenses/>.*/

import React, {useContext, useState} from 'react';
import { Button } from '@material-ui/core';
import styled from 'styled-components'
import {Store} from '../../Store.js'
import CloseIcon from '@material-ui/icons/Close';
import Cropper from '../Cropper.js'
import {makeAxiosPutRequest} from '../HelperFunctions/getAxiosConfig'

export default function ComponentAlterarCover (props) {
    const {state, dispatch} = useContext(Store)

    // eslint-disable-next-line
    const [tempImgURL, setTempImg] = useState(props.cover)
    const [newCover, setNewCover] = useState('')
    const updateCover = (cover) => {setNewCover(cover)}
    const [crop] = useState({
        unit: "%" ,
        width : 100,
        aspect: 16 / 9
    });

    function handleSuccess (data) {
        const target = state.currentUser
        const source = {userCover : data.cover}
        dispatch({
            type : 'USER_CHANGED_COVER',
            currUser : Object.assign(target, source)
        })
    }

    const completeSelection = () => {
        const url = `/users/${props.id}`

        //newCover is a base64 encoded image file.
        let fdCover = new FormData()
        fdCover.set('user[cover]', newCover)

        makeAxiosPutRequest(url, fdCover, handleSuccess, (error) => {console.log(error)})
    }

    return (
            <ModalDiv>
            <HeaderDiv>
                <span style={{width:"32px"}}/>
                    <StyledH2>Editar Capa do Perfil</StyledH2>
                    <StyledCloseModalButton onClick={props.handleClose}>
                        <CloseIcon style={{color : "#666"}}/>
                    </StyledCloseModalButton>
            </HeaderDiv>
            <DialogDiv>
                <EditarDiv>
                    <TextoEditarDiv>
                        Clique nos ícones e arraste para selecionar a parte que você quer da foto
                    </TextoEditarDiv>
                    <div style={{maxWidth : "500px", maxHeight : "300px"}}>
                        <Cropper src={tempImgURL} crop={crop} update={updateCover}/>
                    </div>
                </EditarDiv>
                <FooterButtonsDiv>
                    <ButtonCancelar>ESCOLHER OUTRA</ButtonCancelar>
                    <div>
                        <ButtonCancelar onClick={props.handleClose}>CANCELAR</ButtonCancelar>
                        <ButtonConfirmar onClick={() => {completeSelection()}}>SELECIONAR FOTO</ButtonConfirmar>
                    </div>
                </FooterButtonsDiv>
            </DialogDiv>
            </ModalDiv>
        )

}

const ButtonCancelar = styled(Button)`
    &:hover {
        background-color : rgba(158,158,158,0.2) !important;
    }
    background-color : #fff !important;
    color : #666 !important;
    text-decoration : none !important;
    outline : none !important;
    text-align : center !important;
`
const ButtonConfirmar = styled(Button)`
    background-color : #00bcd4 !important;
    color : #fff !important;
    border-radius : 3px !important;
`

const FooterButtonsDiv = styled.div`
    padding : 0 30px 20px;
    display : flex;
    flex-direction : row;
    align-content : center;
    justify-content : space-between;
    Button {
        margin-top : 20px;
    }
`


const TextoEditarDiv = styled.div`
    margin-bottom : 15px;
    align-self : center;
    text-align : center;
    font-size : 15px;
`

const EditarDiv = styled.div`
    position : relative;
    background-color : #f4f4f4;
    padding : 20px 30px 40px;
`

const ModalDiv = styled.div`
background-color : #fff;
border-radius : 4px;
min-width : 560px;
color : #666;
display: flex;
flex-direction : column;
@media screen and (max-width: 959px) {
    height : 100%;
    width : 100%;
}
`

const DialogDiv = styled.div`
padding : 20px 30px;
overflow : visible !important;
`

const HeaderDiv = styled.div`
display : flex;
flex-direction : row;
align-items : center;
align-content : center;
justify-content : space-between;
max-width : 100%;
`
const StyledH2 = styled.h2`
font-size : 26px;
font-weight : normal;
margin-top : 20px;
margin-bottom : 10px;
font-family: inherit;
line-height: 1.1;
color: inherit;
`
const StyledCloseModalButton = styled(Button)`
display : inline-block;
position : relative;
float : right !important;
background : transparent !important;
min-width: 0 !important;
width : 40px;
border-radius : 50%;
padding : 8px;
height : 40px;
margin : 0 6px;
`
