/*Copyright (C) 2019 Centro de Computacao Cientifica e Software Livre
Departamento de Informatica - Universidade Federal do Parana

This file is part of Plataforma Integrada MEC.

Plataforma Integrada MEC is free software: you can redistribute it and/or modify
it under the terms of the GNU Affero General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

Plataforma Integrada MEC is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Affero General Public License for more details.

You should have received a copy of the GNU Affero General Public License
along with Plataforma Integrada MEC.  If not, see <http://www.gnu.org/licenses/>.*/

import React, {useState, useEffect} from 'react'
import LoadingSpinner from '../../LoadingSpinner.js'
import TemplateCuradoria from '../PanelComponents/TemplateCuradoria.js'
import {makeAxiosGetRequest} from '../../HelperFunctions/getAxiosConfig'

export default function TabPanelCuradoria (props) {
    const [loading, handleLoading] = useState(true)

    const [submissions, setSubmissions] = useState([])
    const [submissionsSlice, setSubmissionsSlice] = useState([])

    const showMoreSubmissions = () => {
        var sliceLength = submissionsSlice.length
        setSubmissionsSlice(submissions.slice(0, sliceLength + 4))
    }

    const showAllSubmissions = () => {setSubmissionsSlice(submissions)}

    function handleSuccess (data) {
        handleLoading(false)
        setSubmissions(data)
        setSubmissionsSlice(data.slice(0,4))
    }
    useEffect( () => {
        const url = `/users/${props.id}/submissions?offset=0&status=submitted`

        makeAxiosGetRequest(url, handleSuccess, (error) => {console.log(error)})
    }, [])

    return (
        <React.Fragment>
            {
                loading ?
                 (
                     <LoadingSpinner text={"Carregando Recursos"}/>
                 )
                 :
                 (
                     [
                         <React.Fragment>
                             <TemplateCuradoria
                                 length={submissions.length}
                                 titleText = {"Recursos a serem curados"}
                                 noContentText = {"Você não tem nenhum recurso para ser avaliado"}
                                 sliceArr={submissionsSlice}
                                 showMore={showMoreSubmissions}
                                 showAll={showAllSubmissions}
                             />
                         </React.Fragment>
                     ]
                 )
             }
        </React.Fragment>
    )
}
