/*Copyright (C) 2019 Centro de Computacao Cientifica e Software Livre
Departamento de Informatica - Universidade Federal do Parana

This file is part of Plataforma Integrada MEC.

Plataforma Integrada MEC is free software: you can redistribute it and/or modify
it under the terms of the GNU Affero General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

Plataforma Integrada MEC is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Affero General Public License for more details.

You should have received a copy of the GNU Affero General Public License
along with Plataforma Integrada MEC.  If not, see <http://www.gnu.org/licenses/>.*/

import React from 'react'
import { Button } from '@material-ui/core';
import Modal from '@material-ui/core/Modal';
import Backdrop from '@material-ui/core/Backdrop';
import Fade from '@material-ui/core/Fade';
import styled from 'styled-components'
import {Link} from 'react-router-dom'
import {makeAxiosDeleteRequest} from '../HelperFunctions/getAxiosConfig.js'

export default function ModalCancelar (props) {

    function handleSuccess (data) {
        props.handleClose()
        console.log('ir pra home')

    }
    const handleDelete = () => {
        // {/*delete the draft*/}
        if (props.draftID) {
            const url = `/learning_objects/${props.draftID}`

            makeAxiosDeleteRequest(url, handleSuccess, (error) => {console.log(error)})
        }
    }

    return (
        <StyledModal
            aria-labelledby="transition-modal-title"
            aria-describedby="transition-modal-description"
            open={props.open}
            centered="true"
            closeAfterTransition
            BackdropComponent={Backdrop}
            onClose={props.handleClose}
            BackdropProps={{
                timeout: 500,
            }}
        >
            <Fade in={props.open}>
                <Container>
                    <Content>
                        <h2>Tem certeza que deseja cancelar?</h2>
                        <p>Ao clicar no botão "OK", o seu recurso NÃO será salvo.</p>
                    </Content>
                    <ButtonsArea>
                        <StyledButton onClick={props.handleClose}>VOLTAR</StyledButton>
                        <Link to="/" style={{textDecoration : "none !important"}}>
                            <StyledButton onClick={handleDelete}>OK</StyledButton>
                        </Link>
                    </ButtonsArea>
                </Container>
            </Fade>
        </StyledModal>
    )
}

const ButtonsArea = styled.div`
    display : flex;
    align-items : center;
    justify-content : flex-end;
    padding-right : 8px;
    padding-left : 16px;
    min-height : 52px;
`

const Content = styled.div`
    padding : 24px;
    overflow : visible;
    max-width : 470px;
    h2 {
        margin-top : 0;
        font-size : 20px;
        font-weight : bold;
        color : #666;
        margin-bottom : 10px;
    }

    p {
        margin : 0 0 10px;
        font-size : 14px;
        color : #666;
    }
`


const StyledModal = styled(Modal)`
    .djXaxP{
        margin : 0 !important;
    }
    display : flex;
    align-items: center;
    justify-content : center;
    padding : 10px !important;
    max-width : none;
    max-height : none;
`

const Container = styled.div`
    box-sizing : border-box;
    background-color : white;
    max-width : none;
    align : center;
    display : flex;
    flex-direction : column;
    min-width : 240px;
    max-height : none;
    position : relative;
    border-radius : 4px;
    box-shadow : 0 7px 8px -4px rgba(0,0,0,.2),0 13px 19px 2px rgba(0,0,0,.14),0 5px 24px 4px rgba(0,0,0,.12);

    @media screen and (max-width : 899px) {
        width : 100%;
        height : 100%;
    }
`
const StyledButton = styled(Button)`
    &:hover {
        background-color : rgba(158,158,158,0.2) !important;
    }
    max-height : 36px !important;

    background-color : transparent !important;
    color : #00bcd4 !important;
    text-decoration : none !important;
    outline : none !important;
    text-align : center !important;

    .button-text {
        cursor : pointer;
        line-height : 36px;
        text-align : center;
        color : currentColor;
        white-space : nowrap;
        text-transform : uppercase;
        font-weight : 600 !important;
        font-size : 14px;
        font-style : inherit;
        font-variant : inherit;
        padding : 6px 16px !important;
    }
`
