/*Copyright (C) 2019 Centro de Computacao Cientifica e Software Livre
Departamento de Informatica - Universidade Federal do Parana

This file is part of Plataforma Integrada MEC.

Plataforma Integrada MEC is free software: you can redistribute it and/or modify
it under the terms of the GNU Affero General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

Plataforma Integrada MEC is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Affero General Public License for more details.

You should have received a copy of the GNU Affero General Public License
along with Plataforma Integrada MEC.  If not, see <http://www.gnu.org/licenses/>.*/

import React, {useState, useEffect} from 'react'
import Grid from '@material-ui/core/Grid';
import ButtonsDiv from './ButtonsDiv.js'
import SobreORecurso from './Forms/SobreORecurso.js'
import NewTitle from './Forms/NewTitle.js'
import Keywords from './Forms/Keywords.js'
import Autor from './Forms/Autor.js'
import TipoDeRecurso from './Forms/TipoDeRecurso.js'
import Idioma from './Forms/Idioma.js'
import {SendInfo} from './SendInfo.js'
import {makeAxiosGetRequest} from '../HelperFunctions/getAxiosConfig.js'

export default function PartOne (props) {
    // {/*const [subjects, setSubjects] = useState([])*/}
    const [languages, setLanguages] = useState([])
    const [objTypes, setObjTypes] = useState([])

    function handleSuccessGetObjTypes (data) {
        setObjTypes(data.sort((a, b) => (a.name) > (b.name) ? 1 : -1))
    }
    useEffect( () => {
            makeAxiosGetRequest(`/object_types/`, handleSuccessGetObjTypes, (error) => {console.log(error)})

            makeAxiosGetRequest(`/languages/`, (data) => {setLanguages(data)}, (error) => {console.log(error)})
    }, [])

    const handleSubmit = () => {
        props.stepperControl(1)
    }

    return (
        <form onSubmit={handleSubmit}>
            {/*------------------------------Titulo-----------------------------------------*/}
            <Grid item xs={12} style={{paddingBottom : "40px"}}>
                <NewTitle draftID={props.draftID} onBlurCallback={SendInfo}/>
            </Grid>

            {/*------------------------------Sobre------------------------------------------*/}
            <Grid item xs={12} style={{paddingBottom : "40px"}}>
                <SobreORecurso draftID={props.draftID} onBlurCallback={SendInfo}/>
            </Grid>

            {/*------------------------------Palavras-chave------------------------------------------*/}
            <Grid item xs={12} style={{paddingBottom : "40px"}}>
                <Keywords  draftID={props.draftID} onBlurCallback={SendInfo}/>
            </Grid>

            {/*------------------------------Autor------------------------------------------*/}
            <Grid item xs={12} style={{paddingBottom : "40px"}}>
                <Autor  draftID={props.draftID} onBlurCallback={SendInfo}/>
            </Grid>

            {/*------------------------------Tipo do Objeto------------------------------------------*/}
            <Grid item xs={12} style={{paddingBottom : "40px"}}>
                <TipoDeRecurso objTypes={objTypes} draftID={props.draftID} onBlurCallback={SendInfo}/>
            </Grid>

            {/*------------------------------Idioma------------------------------------------*/}
            <Grid item xs={12} style={{paddingBottom : "40px"}}>
              <Idioma languages={languages}  draftID={props.draftID} onBlurCallback={SendInfo}/>
            </Grid>

            {/*------------------------------Botoes------------------------------------------*/}
            <Grid item xs={12}>
                <ButtonsDiv draftID={props.draftID} stepperControl={props.stepperControl}/>
            </Grid>

            <Grid item xs={12} style={{marginTop : "20px"}}>
                <span style={{marginTop : "20px", fontWeight : "200", color : "#a5a5a5", paddingLeft : "10px"}}>
                    * Campos obrigatórios
                </span>
            </Grid>
        </form>
    )
}
